@@ -1,5 +1,5 @@
 package Hailo::Tokenizer::Words;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 use 5.010;
 use utf8;
 use Any::Moose;
@@ -17,8 +17,9 @@ with qw(Hailo::Role::Arguments
 my $DECIMAL    = qr/[.,]/;
 my $NUMBER     = qr/$DECIMAL?\d+(?:$DECIMAL\d+)*/;
 my $APOSTROPHE = qr/['’]/;
-my $APOST_WORD = qr/\w+(?:$APOSTROPHE\w+)*/;
-my $WORD       = qr/$NUMBER|$APOST_WORD/;
+my $APOST_WORD = qr/[[:alpha:]]+(?:$APOSTROPHE(?:[[:alpha:]]+))+/;
+my $PLAIN_WORD = qr/\w+/;
+my $WORD       = qr/$NUMBER|$APOST_WORD|$PLAIN_WORD/;
 
 # capitalization
 # The rest of the regexes are pretty hairy. The goal here is to catch the
@@ -30,7 +31,7 @@ my $CLOSE_QUOTE = qr/['"’“”«»」』›‘]/;
 my $TERMINATOR  = qr/(?:[?!‽]+|(?<!\.)\.)/;
 my $ADDRESS     = qr/:/;
 my $PUNCTUATION = qr/[?!‽,;.:]/;
-my $WORD_BIT    = qr/$APOST_WORD(?:-(?!-))?/;
+my $WORD_BIT    = qr/$WORD(?:-(?!-))?/;
 my $BOUNDARY    = qr/$CLOSE_QUOTE?(?:\s*$TERMINATOR|$ADDRESS)\s+$OPEN_QUOTE?\s*/;
 my $SPLIT_WORD  = qr{(?:$WORD_BIT(?:-$WORD_BIT)+|$WORD_BIT/$WORD_BIT|$WORD_BIT)(?=$PUNCTUATION(?: |$)|$CLOSE_QUOTE|$TERMINATOR| |$)};
 
@@ -45,26 +46,37 @@ sub make_tokens {
 
     my @tokens;
     my @chunks = split /\s+/, $line;
-    for my $chunk (@chunks) {
 
-        my $got_word = 0;
+    # process all whitespace-delimited chunks
+    for my $chunk (@chunks) {
+        my $got_word;
+
         while (length $chunk) {
+            # normal words
             if (my ($word) = $chunk =~ /^($WORD)/) {
                 $chunk =~ s/^\Q$word//;
                 $word = lc($word) if $word ne uc($word);
-                push @tokens, [0, $word];
+                push @tokens, [$self->spacing->{normal}, $word];
                 $got_word = 1;
             }
+            # everything else
             elsif (my ($non_word) = $chunk =~ /^(\W+)/) {
                 $chunk =~ s/^\Q$non_word//;
+
+                # lowercase it if it's not all-uppercase
                 $non_word = lc($non_word) if $non_word ne uc($non_word);
 
-                my $spacing = 0;
+                my $spacing = $self->spacing->{normal};
+
+                # was the previous token a word?
                 if ($got_word) {
-                    $spacing = length $chunk ? 3 : 2;
+                    $spacing = length $chunk
+                        ? $self->spacing->{infix}
+                        : $self->spacing->{postfix};
                 }
+                # do we still have more tokens?
                 elsif (length $chunk) {
-                    $spacing = 1;
+                    $spacing = $self->spacing->{prefix};
                 }
 
                 push @tokens, [$spacing, $non_word];
@@ -87,8 +99,13 @@ sub make_output {
         # and this is not the last token, and the next token is not
         # a postfix/infix token
         if ($pos != $#{ $tokens }
-            && $spacing !~ /[13]/
-            && !($pos < $#{ $tokens } && $tokens->[$pos+1][0] =~ /[23]/)) {
+            && $spacing != $self->spacing->{prefix}
+            && $spacing != $self->spacing->{infix}
+            && !($pos < $#{ $tokens }
+                && ($tokens->[$pos+1][0] == $self->spacing->{postfix}
+                || $tokens->[$pos+1][0] == $self->spacing->{infix})
+                )
+            ) {
             $reply .= ' ';
         }
     }
@@ -108,8 +125,8 @@ sub make_output {
     # end paragraphs with a period when it makes sense
     $reply =~ s/(?: |^)$OPEN_QUOTE?$SPLIT_WORD$CLOSE_QUOTE?\K$/./;
 
-    # capitalize I
-    $reply =~ s{ \Ki(?=$APOSTROPHE)}{I}g;
+    # capitalize I'm, I've...
+    $reply =~ s{(?: |$OPEN_QUOTE)\Ki(?=$APOSTROPHE(?:[[:alpha:]]))}{I}g;
 
     return $reply;
 }
